"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5105 import (
        AbstractAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5106 import (
        AbstractShaftCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5107 import (
        AbstractShaftOrHousingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5108 import (
        AbstractShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5109 import (
        AGMAGleasonConicalGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5110 import (
        AGMAGleasonConicalGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5111 import (
        AGMAGleasonConicalGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5112 import (
        AssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5113 import (
        BearingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5114 import (
        BeltConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5115 import (
        BeltDriveCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5116 import (
        BevelDifferentialGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5117 import (
        BevelDifferentialGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5118 import (
        BevelDifferentialGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5119 import (
        BevelDifferentialPlanetGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5120 import (
        BevelDifferentialSunGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5121 import (
        BevelGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5122 import (
        BevelGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5123 import (
        BevelGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5124 import (
        BoltCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5125 import (
        BoltedJointCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5126 import (
        ClutchCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5127 import (
        ClutchConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5128 import (
        ClutchHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5129 import (
        CoaxialConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5130 import (
        ComponentCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5131 import (
        ConceptCouplingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5132 import (
        ConceptCouplingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5133 import (
        ConceptCouplingHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5134 import (
        ConceptGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5135 import (
        ConceptGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5136 import (
        ConceptGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5137 import (
        ConicalGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5138 import (
        ConicalGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5139 import (
        ConicalGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5140 import (
        ConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5141 import (
        ConnectorCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5142 import (
        CouplingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5143 import (
        CouplingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5144 import (
        CouplingHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5145 import (
        CVTBeltConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5146 import (
        CVTCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5147 import (
        CVTPulleyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5148 import (
        CycloidalAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5149 import (
        CycloidalDiscCentralBearingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5150 import (
        CycloidalDiscCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5151 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5152 import (
        CylindricalGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5153 import (
        CylindricalGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5154 import (
        CylindricalGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5155 import (
        CylindricalPlanetGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5156 import (
        DatumCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5157 import (
        ExternalCADModelCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5158 import (
        FaceGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5159 import (
        FaceGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5160 import (
        FaceGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5161 import (
        FEPartCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5162 import (
        FlexiblePinAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5163 import (
        GearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5164 import (
        GearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5165 import (
        GearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5166 import (
        GuideDxfModelCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5167 import (
        HypoidGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5168 import (
        HypoidGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5169 import (
        HypoidGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5170 import (
        InterMountableComponentConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5171 import (
        KlingelnbergCycloPalloidConicalGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5172 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5173 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5174 import (
        KlingelnbergCycloPalloidHypoidGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5175 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5176 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5177 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5178 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5179 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5180 import (
        MassDiscCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5181 import (
        MeasurementComponentCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5182 import (
        MicrophoneArrayCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5183 import (
        MicrophoneCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5184 import (
        MountableComponentCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5185 import (
        OilSealCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5186 import (
        PartCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5187 import (
        PartToPartShearCouplingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5188 import (
        PartToPartShearCouplingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5189 import (
        PartToPartShearCouplingHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5190 import (
        PlanetaryConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5191 import (
        PlanetaryGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5192 import (
        PlanetCarrierCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5193 import (
        PointLoadCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5194 import (
        PowerLoadCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5195 import (
        PulleyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5196 import (
        RingPinsCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5197 import (
        RingPinsToDiscConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5198 import (
        RollingRingAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5199 import (
        RollingRingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5200 import (
        RollingRingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5201 import (
        RootAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5202 import (
        ShaftCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5203 import (
        ShaftHubConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5204 import (
        ShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5205 import (
        SpecialisedAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5206 import (
        SpiralBevelGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5207 import (
        SpiralBevelGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5208 import (
        SpiralBevelGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5209 import (
        SpringDamperCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5210 import (
        SpringDamperConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5211 import (
        SpringDamperHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5212 import (
        StraightBevelDiffGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5213 import (
        StraightBevelDiffGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5214 import (
        StraightBevelDiffGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5215 import (
        StraightBevelGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5216 import (
        StraightBevelGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5217 import (
        StraightBevelGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5218 import (
        StraightBevelPlanetGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5219 import (
        StraightBevelSunGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5220 import (
        SynchroniserCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5221 import (
        SynchroniserHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5222 import (
        SynchroniserPartCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5223 import (
        SynchroniserSleeveCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5224 import (
        TorqueConverterCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5225 import (
        TorqueConverterConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5226 import (
        TorqueConverterPumpCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5227 import (
        TorqueConverterTurbineCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5228 import (
        UnbalancedMassCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5229 import (
        VirtualComponentCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5230 import (
        WormGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5231 import (
        WormGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5232 import (
        WormGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5233 import (
        ZerolBevelGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5234 import (
        ZerolBevelGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5235 import (
        ZerolBevelGearSetCompoundModalAnalysisAtAStiffness,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5105": [
            "AbstractAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5106": [
            "AbstractShaftCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5107": [
            "AbstractShaftOrHousingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5108": [
            "AbstractShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5109": [
            "AGMAGleasonConicalGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5110": [
            "AGMAGleasonConicalGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5111": [
            "AGMAGleasonConicalGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5112": [
            "AssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5113": [
            "BearingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5114": [
            "BeltConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5115": [
            "BeltDriveCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5116": [
            "BevelDifferentialGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5117": [
            "BevelDifferentialGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5118": [
            "BevelDifferentialGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5119": [
            "BevelDifferentialPlanetGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5120": [
            "BevelDifferentialSunGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5121": [
            "BevelGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5122": [
            "BevelGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5123": [
            "BevelGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5124": [
            "BoltCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5125": [
            "BoltedJointCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5126": [
            "ClutchCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5127": [
            "ClutchConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5128": [
            "ClutchHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5129": [
            "CoaxialConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5130": [
            "ComponentCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5131": [
            "ConceptCouplingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5132": [
            "ConceptCouplingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5133": [
            "ConceptCouplingHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5134": [
            "ConceptGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5135": [
            "ConceptGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5136": [
            "ConceptGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5137": [
            "ConicalGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5138": [
            "ConicalGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5139": [
            "ConicalGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5140": [
            "ConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5141": [
            "ConnectorCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5142": [
            "CouplingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5143": [
            "CouplingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5144": [
            "CouplingHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5145": [
            "CVTBeltConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5146": [
            "CVTCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5147": [
            "CVTPulleyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5148": [
            "CycloidalAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5149": [
            "CycloidalDiscCentralBearingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5150": [
            "CycloidalDiscCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5151": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5152": [
            "CylindricalGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5153": [
            "CylindricalGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5154": [
            "CylindricalGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5155": [
            "CylindricalPlanetGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5156": [
            "DatumCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5157": [
            "ExternalCADModelCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5158": [
            "FaceGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5159": [
            "FaceGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5160": [
            "FaceGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5161": [
            "FEPartCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5162": [
            "FlexiblePinAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5163": [
            "GearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5164": [
            "GearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5165": [
            "GearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5166": [
            "GuideDxfModelCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5167": [
            "HypoidGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5168": [
            "HypoidGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5169": [
            "HypoidGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5170": [
            "InterMountableComponentConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5171": [
            "KlingelnbergCycloPalloidConicalGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5172": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5173": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5174": [
            "KlingelnbergCycloPalloidHypoidGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5175": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5176": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5177": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5178": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5179": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5180": [
            "MassDiscCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5181": [
            "MeasurementComponentCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5182": [
            "MicrophoneArrayCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5183": [
            "MicrophoneCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5184": [
            "MountableComponentCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5185": [
            "OilSealCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5186": [
            "PartCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5187": [
            "PartToPartShearCouplingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5188": [
            "PartToPartShearCouplingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5189": [
            "PartToPartShearCouplingHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5190": [
            "PlanetaryConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5191": [
            "PlanetaryGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5192": [
            "PlanetCarrierCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5193": [
            "PointLoadCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5194": [
            "PowerLoadCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5195": [
            "PulleyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5196": [
            "RingPinsCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5197": [
            "RingPinsToDiscConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5198": [
            "RollingRingAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5199": [
            "RollingRingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5200": [
            "RollingRingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5201": [
            "RootAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5202": [
            "ShaftCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5203": [
            "ShaftHubConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5204": [
            "ShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5205": [
            "SpecialisedAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5206": [
            "SpiralBevelGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5207": [
            "SpiralBevelGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5208": [
            "SpiralBevelGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5209": [
            "SpringDamperCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5210": [
            "SpringDamperConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5211": [
            "SpringDamperHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5212": [
            "StraightBevelDiffGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5213": [
            "StraightBevelDiffGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5214": [
            "StraightBevelDiffGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5215": [
            "StraightBevelGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5216": [
            "StraightBevelGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5217": [
            "StraightBevelGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5218": [
            "StraightBevelPlanetGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5219": [
            "StraightBevelSunGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5220": [
            "SynchroniserCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5221": [
            "SynchroniserHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5222": [
            "SynchroniserPartCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5223": [
            "SynchroniserSleeveCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5224": [
            "TorqueConverterCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5225": [
            "TorqueConverterConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5226": [
            "TorqueConverterPumpCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5227": [
            "TorqueConverterTurbineCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5228": [
            "UnbalancedMassCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5229": [
            "VirtualComponentCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5230": [
            "WormGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5231": [
            "WormGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5232": [
            "WormGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5233": [
            "ZerolBevelGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5234": [
            "ZerolBevelGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5235": [
            "ZerolBevelGearSetCompoundModalAnalysisAtAStiffness"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundModalAnalysisAtAStiffness",
    "AbstractShaftCompoundModalAnalysisAtAStiffness",
    "AbstractShaftOrHousingCompoundModalAnalysisAtAStiffness",
    "AbstractShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness",
    "AGMAGleasonConicalGearCompoundModalAnalysisAtAStiffness",
    "AGMAGleasonConicalGearMeshCompoundModalAnalysisAtAStiffness",
    "AGMAGleasonConicalGearSetCompoundModalAnalysisAtAStiffness",
    "AssemblyCompoundModalAnalysisAtAStiffness",
    "BearingCompoundModalAnalysisAtAStiffness",
    "BeltConnectionCompoundModalAnalysisAtAStiffness",
    "BeltDriveCompoundModalAnalysisAtAStiffness",
    "BevelDifferentialGearCompoundModalAnalysisAtAStiffness",
    "BevelDifferentialGearMeshCompoundModalAnalysisAtAStiffness",
    "BevelDifferentialGearSetCompoundModalAnalysisAtAStiffness",
    "BevelDifferentialPlanetGearCompoundModalAnalysisAtAStiffness",
    "BevelDifferentialSunGearCompoundModalAnalysisAtAStiffness",
    "BevelGearCompoundModalAnalysisAtAStiffness",
    "BevelGearMeshCompoundModalAnalysisAtAStiffness",
    "BevelGearSetCompoundModalAnalysisAtAStiffness",
    "BoltCompoundModalAnalysisAtAStiffness",
    "BoltedJointCompoundModalAnalysisAtAStiffness",
    "ClutchCompoundModalAnalysisAtAStiffness",
    "ClutchConnectionCompoundModalAnalysisAtAStiffness",
    "ClutchHalfCompoundModalAnalysisAtAStiffness",
    "CoaxialConnectionCompoundModalAnalysisAtAStiffness",
    "ComponentCompoundModalAnalysisAtAStiffness",
    "ConceptCouplingCompoundModalAnalysisAtAStiffness",
    "ConceptCouplingConnectionCompoundModalAnalysisAtAStiffness",
    "ConceptCouplingHalfCompoundModalAnalysisAtAStiffness",
    "ConceptGearCompoundModalAnalysisAtAStiffness",
    "ConceptGearMeshCompoundModalAnalysisAtAStiffness",
    "ConceptGearSetCompoundModalAnalysisAtAStiffness",
    "ConicalGearCompoundModalAnalysisAtAStiffness",
    "ConicalGearMeshCompoundModalAnalysisAtAStiffness",
    "ConicalGearSetCompoundModalAnalysisAtAStiffness",
    "ConnectionCompoundModalAnalysisAtAStiffness",
    "ConnectorCompoundModalAnalysisAtAStiffness",
    "CouplingCompoundModalAnalysisAtAStiffness",
    "CouplingConnectionCompoundModalAnalysisAtAStiffness",
    "CouplingHalfCompoundModalAnalysisAtAStiffness",
    "CVTBeltConnectionCompoundModalAnalysisAtAStiffness",
    "CVTCompoundModalAnalysisAtAStiffness",
    "CVTPulleyCompoundModalAnalysisAtAStiffness",
    "CycloidalAssemblyCompoundModalAnalysisAtAStiffness",
    "CycloidalDiscCentralBearingConnectionCompoundModalAnalysisAtAStiffness",
    "CycloidalDiscCompoundModalAnalysisAtAStiffness",
    "CycloidalDiscPlanetaryBearingConnectionCompoundModalAnalysisAtAStiffness",
    "CylindricalGearCompoundModalAnalysisAtAStiffness",
    "CylindricalGearMeshCompoundModalAnalysisAtAStiffness",
    "CylindricalGearSetCompoundModalAnalysisAtAStiffness",
    "CylindricalPlanetGearCompoundModalAnalysisAtAStiffness",
    "DatumCompoundModalAnalysisAtAStiffness",
    "ExternalCADModelCompoundModalAnalysisAtAStiffness",
    "FaceGearCompoundModalAnalysisAtAStiffness",
    "FaceGearMeshCompoundModalAnalysisAtAStiffness",
    "FaceGearSetCompoundModalAnalysisAtAStiffness",
    "FEPartCompoundModalAnalysisAtAStiffness",
    "FlexiblePinAssemblyCompoundModalAnalysisAtAStiffness",
    "GearCompoundModalAnalysisAtAStiffness",
    "GearMeshCompoundModalAnalysisAtAStiffness",
    "GearSetCompoundModalAnalysisAtAStiffness",
    "GuideDxfModelCompoundModalAnalysisAtAStiffness",
    "HypoidGearCompoundModalAnalysisAtAStiffness",
    "HypoidGearMeshCompoundModalAnalysisAtAStiffness",
    "HypoidGearSetCompoundModalAnalysisAtAStiffness",
    "InterMountableComponentConnectionCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidConicalGearCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidConicalGearSetCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidHypoidGearCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundModalAnalysisAtAStiffness",
    "MassDiscCompoundModalAnalysisAtAStiffness",
    "MeasurementComponentCompoundModalAnalysisAtAStiffness",
    "MicrophoneArrayCompoundModalAnalysisAtAStiffness",
    "MicrophoneCompoundModalAnalysisAtAStiffness",
    "MountableComponentCompoundModalAnalysisAtAStiffness",
    "OilSealCompoundModalAnalysisAtAStiffness",
    "PartCompoundModalAnalysisAtAStiffness",
    "PartToPartShearCouplingCompoundModalAnalysisAtAStiffness",
    "PartToPartShearCouplingConnectionCompoundModalAnalysisAtAStiffness",
    "PartToPartShearCouplingHalfCompoundModalAnalysisAtAStiffness",
    "PlanetaryConnectionCompoundModalAnalysisAtAStiffness",
    "PlanetaryGearSetCompoundModalAnalysisAtAStiffness",
    "PlanetCarrierCompoundModalAnalysisAtAStiffness",
    "PointLoadCompoundModalAnalysisAtAStiffness",
    "PowerLoadCompoundModalAnalysisAtAStiffness",
    "PulleyCompoundModalAnalysisAtAStiffness",
    "RingPinsCompoundModalAnalysisAtAStiffness",
    "RingPinsToDiscConnectionCompoundModalAnalysisAtAStiffness",
    "RollingRingAssemblyCompoundModalAnalysisAtAStiffness",
    "RollingRingCompoundModalAnalysisAtAStiffness",
    "RollingRingConnectionCompoundModalAnalysisAtAStiffness",
    "RootAssemblyCompoundModalAnalysisAtAStiffness",
    "ShaftCompoundModalAnalysisAtAStiffness",
    "ShaftHubConnectionCompoundModalAnalysisAtAStiffness",
    "ShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness",
    "SpecialisedAssemblyCompoundModalAnalysisAtAStiffness",
    "SpiralBevelGearCompoundModalAnalysisAtAStiffness",
    "SpiralBevelGearMeshCompoundModalAnalysisAtAStiffness",
    "SpiralBevelGearSetCompoundModalAnalysisAtAStiffness",
    "SpringDamperCompoundModalAnalysisAtAStiffness",
    "SpringDamperConnectionCompoundModalAnalysisAtAStiffness",
    "SpringDamperHalfCompoundModalAnalysisAtAStiffness",
    "StraightBevelDiffGearCompoundModalAnalysisAtAStiffness",
    "StraightBevelDiffGearMeshCompoundModalAnalysisAtAStiffness",
    "StraightBevelDiffGearSetCompoundModalAnalysisAtAStiffness",
    "StraightBevelGearCompoundModalAnalysisAtAStiffness",
    "StraightBevelGearMeshCompoundModalAnalysisAtAStiffness",
    "StraightBevelGearSetCompoundModalAnalysisAtAStiffness",
    "StraightBevelPlanetGearCompoundModalAnalysisAtAStiffness",
    "StraightBevelSunGearCompoundModalAnalysisAtAStiffness",
    "SynchroniserCompoundModalAnalysisAtAStiffness",
    "SynchroniserHalfCompoundModalAnalysisAtAStiffness",
    "SynchroniserPartCompoundModalAnalysisAtAStiffness",
    "SynchroniserSleeveCompoundModalAnalysisAtAStiffness",
    "TorqueConverterCompoundModalAnalysisAtAStiffness",
    "TorqueConverterConnectionCompoundModalAnalysisAtAStiffness",
    "TorqueConverterPumpCompoundModalAnalysisAtAStiffness",
    "TorqueConverterTurbineCompoundModalAnalysisAtAStiffness",
    "UnbalancedMassCompoundModalAnalysisAtAStiffness",
    "VirtualComponentCompoundModalAnalysisAtAStiffness",
    "WormGearCompoundModalAnalysisAtAStiffness",
    "WormGearMeshCompoundModalAnalysisAtAStiffness",
    "WormGearSetCompoundModalAnalysisAtAStiffness",
    "ZerolBevelGearCompoundModalAnalysisAtAStiffness",
    "ZerolBevelGearMeshCompoundModalAnalysisAtAStiffness",
    "ZerolBevelGearSetCompoundModalAnalysisAtAStiffness",
)



"""PartLoadCase"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal.sentinels import ListWithSelectedItem_None
from mastapy._private._internal import (
    constructor,
    enum_with_selected_value_runtime,
    conversion,
    utility,
)
from mastapy._private._internal.implicit import (
    enum_with_selected_value,
    list_with_selected_item,
)
from mastapy._private.system_model.analyses_and_results.static_loads import _7044, _6951
from mastapy._private.system_model.analyses_and_results import _2740
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_PART_LOAD_CASE = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads", "PartLoadCase"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.part_model import _2524
    from mastapy._private.system_model.analyses_and_results.static_loads import (
        _6952,
        _6953,
        _6954,
        _6955,
        _6960,
        _6962,
        _6965,
        _6966,
        _6968,
        _6969,
        _6971,
        _6972,
        _6973,
        _6974,
        _6976,
        _6977,
        _6978,
        _6980,
        _6981,
        _6984,
        _6986,
        _6987,
        _6988,
        _6990,
        _6991,
        _6995,
        _6997,
        _6999,
        _7000,
        _7002,
        _7003,
        _7004,
        _7006,
        _7008,
        _7012,
        _7013,
        _7016,
        _7030,
        _7031,
        _7033,
        _7034,
        _7035,
        _7037,
        _7042,
        _7043,
        _7052,
        _7054,
        _7059,
        _7061,
        _7062,
        _7064,
        _7065,
        _7067,
        _7068,
        _7069,
        _7071,
        _7072,
        _7073,
        _7075,
        _7079,
        _7080,
        _7082,
        _7084,
        _7087,
        _7088,
        _7089,
        _7092,
        _7094,
        _7096,
        _7097,
        _7098,
        _7099,
        _7101,
        _7102,
        _7104,
        _7106,
        _7107,
        _7108,
        _7110,
        _7111,
        _7113,
        _7114,
        _7115,
        _7116,
        _7117,
        _7118,
        _7119,
        _7122,
        _7123,
        _7124,
        _7129,
        _7130,
        _7131,
        _7133,
        _7134,
        _7136,
    )
    from mastapy._private.electric_machines.harmonic_load_data import _1426
    from mastapy._private.system_model.analyses_and_results import _2736, _2734

    Self = TypeVar("Self", bound="PartLoadCase")
    CastSelf = TypeVar("CastSelf", bound="PartLoadCase._Cast_PartLoadCase")


__docformat__ = "restructuredtext en"
__all__ = ("PartLoadCase",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_PartLoadCase:
    """Special nested class for casting PartLoadCase to subclasses."""

    __parent__: "PartLoadCase"

    @property
    def part_analysis(self: "CastSelf") -> "_2740.PartAnalysis":
        return self.__parent__._cast(_2740.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2736.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2736

        return self.__parent__._cast(_2736.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def abstract_assembly_load_case(
        self: "CastSelf",
    ) -> "_6953.AbstractAssemblyLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6953,
        )

        return self.__parent__._cast(_6953.AbstractAssemblyLoadCase)

    @property
    def abstract_shaft_load_case(self: "CastSelf") -> "_6954.AbstractShaftLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6954,
        )

        return self.__parent__._cast(_6954.AbstractShaftLoadCase)

    @property
    def abstract_shaft_or_housing_load_case(
        self: "CastSelf",
    ) -> "_6955.AbstractShaftOrHousingLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6955,
        )

        return self.__parent__._cast(_6955.AbstractShaftOrHousingLoadCase)

    @property
    def agma_gleason_conical_gear_load_case(
        self: "CastSelf",
    ) -> "_6960.AGMAGleasonConicalGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6960,
        )

        return self.__parent__._cast(_6960.AGMAGleasonConicalGearLoadCase)

    @property
    def agma_gleason_conical_gear_set_load_case(
        self: "CastSelf",
    ) -> "_6962.AGMAGleasonConicalGearSetLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6962,
        )

        return self.__parent__._cast(_6962.AGMAGleasonConicalGearSetLoadCase)

    @property
    def assembly_load_case(self: "CastSelf") -> "_6965.AssemblyLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6965,
        )

        return self.__parent__._cast(_6965.AssemblyLoadCase)

    @property
    def bearing_load_case(self: "CastSelf") -> "_6966.BearingLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6966,
        )

        return self.__parent__._cast(_6966.BearingLoadCase)

    @property
    def belt_drive_load_case(self: "CastSelf") -> "_6968.BeltDriveLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6968,
        )

        return self.__parent__._cast(_6968.BeltDriveLoadCase)

    @property
    def bevel_differential_gear_load_case(
        self: "CastSelf",
    ) -> "_6969.BevelDifferentialGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6969,
        )

        return self.__parent__._cast(_6969.BevelDifferentialGearLoadCase)

    @property
    def bevel_differential_gear_set_load_case(
        self: "CastSelf",
    ) -> "_6971.BevelDifferentialGearSetLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6971,
        )

        return self.__parent__._cast(_6971.BevelDifferentialGearSetLoadCase)

    @property
    def bevel_differential_planet_gear_load_case(
        self: "CastSelf",
    ) -> "_6972.BevelDifferentialPlanetGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6972,
        )

        return self.__parent__._cast(_6972.BevelDifferentialPlanetGearLoadCase)

    @property
    def bevel_differential_sun_gear_load_case(
        self: "CastSelf",
    ) -> "_6973.BevelDifferentialSunGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6973,
        )

        return self.__parent__._cast(_6973.BevelDifferentialSunGearLoadCase)

    @property
    def bevel_gear_load_case(self: "CastSelf") -> "_6974.BevelGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6974,
        )

        return self.__parent__._cast(_6974.BevelGearLoadCase)

    @property
    def bevel_gear_set_load_case(self: "CastSelf") -> "_6976.BevelGearSetLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6976,
        )

        return self.__parent__._cast(_6976.BevelGearSetLoadCase)

    @property
    def bolted_joint_load_case(self: "CastSelf") -> "_6977.BoltedJointLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6977,
        )

        return self.__parent__._cast(_6977.BoltedJointLoadCase)

    @property
    def bolt_load_case(self: "CastSelf") -> "_6978.BoltLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6978,
        )

        return self.__parent__._cast(_6978.BoltLoadCase)

    @property
    def clutch_half_load_case(self: "CastSelf") -> "_6980.ClutchHalfLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6980,
        )

        return self.__parent__._cast(_6980.ClutchHalfLoadCase)

    @property
    def clutch_load_case(self: "CastSelf") -> "_6981.ClutchLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6981,
        )

        return self.__parent__._cast(_6981.ClutchLoadCase)

    @property
    def component_load_case(self: "CastSelf") -> "_6984.ComponentLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6984,
        )

        return self.__parent__._cast(_6984.ComponentLoadCase)

    @property
    def concept_coupling_half_load_case(
        self: "CastSelf",
    ) -> "_6986.ConceptCouplingHalfLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6986,
        )

        return self.__parent__._cast(_6986.ConceptCouplingHalfLoadCase)

    @property
    def concept_coupling_load_case(self: "CastSelf") -> "_6987.ConceptCouplingLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6987,
        )

        return self.__parent__._cast(_6987.ConceptCouplingLoadCase)

    @property
    def concept_gear_load_case(self: "CastSelf") -> "_6988.ConceptGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6988,
        )

        return self.__parent__._cast(_6988.ConceptGearLoadCase)

    @property
    def concept_gear_set_load_case(self: "CastSelf") -> "_6990.ConceptGearSetLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6990,
        )

        return self.__parent__._cast(_6990.ConceptGearSetLoadCase)

    @property
    def conical_gear_load_case(self: "CastSelf") -> "_6991.ConicalGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6991,
        )

        return self.__parent__._cast(_6991.ConicalGearLoadCase)

    @property
    def conical_gear_set_load_case(self: "CastSelf") -> "_6995.ConicalGearSetLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6995,
        )

        return self.__parent__._cast(_6995.ConicalGearSetLoadCase)

    @property
    def connector_load_case(self: "CastSelf") -> "_6997.ConnectorLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6997,
        )

        return self.__parent__._cast(_6997.ConnectorLoadCase)

    @property
    def coupling_half_load_case(self: "CastSelf") -> "_6999.CouplingHalfLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6999,
        )

        return self.__parent__._cast(_6999.CouplingHalfLoadCase)

    @property
    def coupling_load_case(self: "CastSelf") -> "_7000.CouplingLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7000,
        )

        return self.__parent__._cast(_7000.CouplingLoadCase)

    @property
    def cvt_load_case(self: "CastSelf") -> "_7002.CVTLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7002,
        )

        return self.__parent__._cast(_7002.CVTLoadCase)

    @property
    def cvt_pulley_load_case(self: "CastSelf") -> "_7003.CVTPulleyLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7003,
        )

        return self.__parent__._cast(_7003.CVTPulleyLoadCase)

    @property
    def cycloidal_assembly_load_case(
        self: "CastSelf",
    ) -> "_7004.CycloidalAssemblyLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7004,
        )

        return self.__parent__._cast(_7004.CycloidalAssemblyLoadCase)

    @property
    def cycloidal_disc_load_case(self: "CastSelf") -> "_7006.CycloidalDiscLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7006,
        )

        return self.__parent__._cast(_7006.CycloidalDiscLoadCase)

    @property
    def cylindrical_gear_load_case(self: "CastSelf") -> "_7008.CylindricalGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7008,
        )

        return self.__parent__._cast(_7008.CylindricalGearLoadCase)

    @property
    def cylindrical_gear_set_load_case(
        self: "CastSelf",
    ) -> "_7012.CylindricalGearSetLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7012,
        )

        return self.__parent__._cast(_7012.CylindricalGearSetLoadCase)

    @property
    def cylindrical_planet_gear_load_case(
        self: "CastSelf",
    ) -> "_7013.CylindricalPlanetGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7013,
        )

        return self.__parent__._cast(_7013.CylindricalPlanetGearLoadCase)

    @property
    def datum_load_case(self: "CastSelf") -> "_7016.DatumLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7016,
        )

        return self.__parent__._cast(_7016.DatumLoadCase)

    @property
    def external_cad_model_load_case(
        self: "CastSelf",
    ) -> "_7030.ExternalCADModelLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7030,
        )

        return self.__parent__._cast(_7030.ExternalCADModelLoadCase)

    @property
    def face_gear_load_case(self: "CastSelf") -> "_7031.FaceGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7031,
        )

        return self.__parent__._cast(_7031.FaceGearLoadCase)

    @property
    def face_gear_set_load_case(self: "CastSelf") -> "_7033.FaceGearSetLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7033,
        )

        return self.__parent__._cast(_7033.FaceGearSetLoadCase)

    @property
    def fe_part_load_case(self: "CastSelf") -> "_7034.FEPartLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7034,
        )

        return self.__parent__._cast(_7034.FEPartLoadCase)

    @property
    def flexible_pin_assembly_load_case(
        self: "CastSelf",
    ) -> "_7035.FlexiblePinAssemblyLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7035,
        )

        return self.__parent__._cast(_7035.FlexiblePinAssemblyLoadCase)

    @property
    def gear_load_case(self: "CastSelf") -> "_7037.GearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7037,
        )

        return self.__parent__._cast(_7037.GearLoadCase)

    @property
    def gear_set_load_case(self: "CastSelf") -> "_7042.GearSetLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7042,
        )

        return self.__parent__._cast(_7042.GearSetLoadCase)

    @property
    def guide_dxf_model_load_case(self: "CastSelf") -> "_7043.GuideDxfModelLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7043,
        )

        return self.__parent__._cast(_7043.GuideDxfModelLoadCase)

    @property
    def hypoid_gear_load_case(self: "CastSelf") -> "_7052.HypoidGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7052,
        )

        return self.__parent__._cast(_7052.HypoidGearLoadCase)

    @property
    def hypoid_gear_set_load_case(self: "CastSelf") -> "_7054.HypoidGearSetLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7054,
        )

        return self.__parent__._cast(_7054.HypoidGearSetLoadCase)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_load_case(
        self: "CastSelf",
    ) -> "_7059.KlingelnbergCycloPalloidConicalGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7059,
        )

        return self.__parent__._cast(_7059.KlingelnbergCycloPalloidConicalGearLoadCase)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_set_load_case(
        self: "CastSelf",
    ) -> "_7061.KlingelnbergCycloPalloidConicalGearSetLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7061,
        )

        return self.__parent__._cast(
            _7061.KlingelnbergCycloPalloidConicalGearSetLoadCase
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_load_case(
        self: "CastSelf",
    ) -> "_7062.KlingelnbergCycloPalloidHypoidGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7062,
        )

        return self.__parent__._cast(_7062.KlingelnbergCycloPalloidHypoidGearLoadCase)

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_set_load_case(
        self: "CastSelf",
    ) -> "_7064.KlingelnbergCycloPalloidHypoidGearSetLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7064,
        )

        return self.__parent__._cast(
            _7064.KlingelnbergCycloPalloidHypoidGearSetLoadCase
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_load_case(
        self: "CastSelf",
    ) -> "_7065.KlingelnbergCycloPalloidSpiralBevelGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7065,
        )

        return self.__parent__._cast(
            _7065.KlingelnbergCycloPalloidSpiralBevelGearLoadCase
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_set_load_case(
        self: "CastSelf",
    ) -> "_7067.KlingelnbergCycloPalloidSpiralBevelGearSetLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7067,
        )

        return self.__parent__._cast(
            _7067.KlingelnbergCycloPalloidSpiralBevelGearSetLoadCase
        )

    @property
    def mass_disc_load_case(self: "CastSelf") -> "_7068.MassDiscLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7068,
        )

        return self.__parent__._cast(_7068.MassDiscLoadCase)

    @property
    def measurement_component_load_case(
        self: "CastSelf",
    ) -> "_7069.MeasurementComponentLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7069,
        )

        return self.__parent__._cast(_7069.MeasurementComponentLoadCase)

    @property
    def microphone_array_load_case(self: "CastSelf") -> "_7071.MicrophoneArrayLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7071,
        )

        return self.__parent__._cast(_7071.MicrophoneArrayLoadCase)

    @property
    def microphone_load_case(self: "CastSelf") -> "_7072.MicrophoneLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7072,
        )

        return self.__parent__._cast(_7072.MicrophoneLoadCase)

    @property
    def mountable_component_load_case(
        self: "CastSelf",
    ) -> "_7073.MountableComponentLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7073,
        )

        return self.__parent__._cast(_7073.MountableComponentLoadCase)

    @property
    def oil_seal_load_case(self: "CastSelf") -> "_7075.OilSealLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7075,
        )

        return self.__parent__._cast(_7075.OilSealLoadCase)

    @property
    def part_to_part_shear_coupling_half_load_case(
        self: "CastSelf",
    ) -> "_7079.PartToPartShearCouplingHalfLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7079,
        )

        return self.__parent__._cast(_7079.PartToPartShearCouplingHalfLoadCase)

    @property
    def part_to_part_shear_coupling_load_case(
        self: "CastSelf",
    ) -> "_7080.PartToPartShearCouplingLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7080,
        )

        return self.__parent__._cast(_7080.PartToPartShearCouplingLoadCase)

    @property
    def planetary_gear_set_load_case(
        self: "CastSelf",
    ) -> "_7082.PlanetaryGearSetLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7082,
        )

        return self.__parent__._cast(_7082.PlanetaryGearSetLoadCase)

    @property
    def planet_carrier_load_case(self: "CastSelf") -> "_7084.PlanetCarrierLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7084,
        )

        return self.__parent__._cast(_7084.PlanetCarrierLoadCase)

    @property
    def point_load_load_case(self: "CastSelf") -> "_7087.PointLoadLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7087,
        )

        return self.__parent__._cast(_7087.PointLoadLoadCase)

    @property
    def power_load_load_case(self: "CastSelf") -> "_7088.PowerLoadLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7088,
        )

        return self.__parent__._cast(_7088.PowerLoadLoadCase)

    @property
    def pulley_load_case(self: "CastSelf") -> "_7089.PulleyLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7089,
        )

        return self.__parent__._cast(_7089.PulleyLoadCase)

    @property
    def ring_pins_load_case(self: "CastSelf") -> "_7092.RingPinsLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7092,
        )

        return self.__parent__._cast(_7092.RingPinsLoadCase)

    @property
    def rolling_ring_assembly_load_case(
        self: "CastSelf",
    ) -> "_7094.RollingRingAssemblyLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7094,
        )

        return self.__parent__._cast(_7094.RollingRingAssemblyLoadCase)

    @property
    def rolling_ring_load_case(self: "CastSelf") -> "_7096.RollingRingLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7096,
        )

        return self.__parent__._cast(_7096.RollingRingLoadCase)

    @property
    def root_assembly_load_case(self: "CastSelf") -> "_7097.RootAssemblyLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7097,
        )

        return self.__parent__._cast(_7097.RootAssemblyLoadCase)

    @property
    def shaft_hub_connection_load_case(
        self: "CastSelf",
    ) -> "_7098.ShaftHubConnectionLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7098,
        )

        return self.__parent__._cast(_7098.ShaftHubConnectionLoadCase)

    @property
    def shaft_load_case(self: "CastSelf") -> "_7099.ShaftLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7099,
        )

        return self.__parent__._cast(_7099.ShaftLoadCase)

    @property
    def specialised_assembly_load_case(
        self: "CastSelf",
    ) -> "_7101.SpecialisedAssemblyLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7101,
        )

        return self.__parent__._cast(_7101.SpecialisedAssemblyLoadCase)

    @property
    def spiral_bevel_gear_load_case(
        self: "CastSelf",
    ) -> "_7102.SpiralBevelGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7102,
        )

        return self.__parent__._cast(_7102.SpiralBevelGearLoadCase)

    @property
    def spiral_bevel_gear_set_load_case(
        self: "CastSelf",
    ) -> "_7104.SpiralBevelGearSetLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7104,
        )

        return self.__parent__._cast(_7104.SpiralBevelGearSetLoadCase)

    @property
    def spring_damper_half_load_case(
        self: "CastSelf",
    ) -> "_7106.SpringDamperHalfLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7106,
        )

        return self.__parent__._cast(_7106.SpringDamperHalfLoadCase)

    @property
    def spring_damper_load_case(self: "CastSelf") -> "_7107.SpringDamperLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7107,
        )

        return self.__parent__._cast(_7107.SpringDamperLoadCase)

    @property
    def straight_bevel_diff_gear_load_case(
        self: "CastSelf",
    ) -> "_7108.StraightBevelDiffGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7108,
        )

        return self.__parent__._cast(_7108.StraightBevelDiffGearLoadCase)

    @property
    def straight_bevel_diff_gear_set_load_case(
        self: "CastSelf",
    ) -> "_7110.StraightBevelDiffGearSetLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7110,
        )

        return self.__parent__._cast(_7110.StraightBevelDiffGearSetLoadCase)

    @property
    def straight_bevel_gear_load_case(
        self: "CastSelf",
    ) -> "_7111.StraightBevelGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7111,
        )

        return self.__parent__._cast(_7111.StraightBevelGearLoadCase)

    @property
    def straight_bevel_gear_set_load_case(
        self: "CastSelf",
    ) -> "_7113.StraightBevelGearSetLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7113,
        )

        return self.__parent__._cast(_7113.StraightBevelGearSetLoadCase)

    @property
    def straight_bevel_planet_gear_load_case(
        self: "CastSelf",
    ) -> "_7114.StraightBevelPlanetGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7114,
        )

        return self.__parent__._cast(_7114.StraightBevelPlanetGearLoadCase)

    @property
    def straight_bevel_sun_gear_load_case(
        self: "CastSelf",
    ) -> "_7115.StraightBevelSunGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7115,
        )

        return self.__parent__._cast(_7115.StraightBevelSunGearLoadCase)

    @property
    def synchroniser_half_load_case(
        self: "CastSelf",
    ) -> "_7116.SynchroniserHalfLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7116,
        )

        return self.__parent__._cast(_7116.SynchroniserHalfLoadCase)

    @property
    def synchroniser_load_case(self: "CastSelf") -> "_7117.SynchroniserLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7117,
        )

        return self.__parent__._cast(_7117.SynchroniserLoadCase)

    @property
    def synchroniser_part_load_case(
        self: "CastSelf",
    ) -> "_7118.SynchroniserPartLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7118,
        )

        return self.__parent__._cast(_7118.SynchroniserPartLoadCase)

    @property
    def synchroniser_sleeve_load_case(
        self: "CastSelf",
    ) -> "_7119.SynchroniserSleeveLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7119,
        )

        return self.__parent__._cast(_7119.SynchroniserSleeveLoadCase)

    @property
    def torque_converter_load_case(self: "CastSelf") -> "_7122.TorqueConverterLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7122,
        )

        return self.__parent__._cast(_7122.TorqueConverterLoadCase)

    @property
    def torque_converter_pump_load_case(
        self: "CastSelf",
    ) -> "_7123.TorqueConverterPumpLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7123,
        )

        return self.__parent__._cast(_7123.TorqueConverterPumpLoadCase)

    @property
    def torque_converter_turbine_load_case(
        self: "CastSelf",
    ) -> "_7124.TorqueConverterTurbineLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7124,
        )

        return self.__parent__._cast(_7124.TorqueConverterTurbineLoadCase)

    @property
    def unbalanced_mass_load_case(self: "CastSelf") -> "_7129.UnbalancedMassLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7129,
        )

        return self.__parent__._cast(_7129.UnbalancedMassLoadCase)

    @property
    def virtual_component_load_case(
        self: "CastSelf",
    ) -> "_7130.VirtualComponentLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7130,
        )

        return self.__parent__._cast(_7130.VirtualComponentLoadCase)

    @property
    def worm_gear_load_case(self: "CastSelf") -> "_7131.WormGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7131,
        )

        return self.__parent__._cast(_7131.WormGearLoadCase)

    @property
    def worm_gear_set_load_case(self: "CastSelf") -> "_7133.WormGearSetLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7133,
        )

        return self.__parent__._cast(_7133.WormGearSetLoadCase)

    @property
    def zerol_bevel_gear_load_case(self: "CastSelf") -> "_7134.ZerolBevelGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7134,
        )

        return self.__parent__._cast(_7134.ZerolBevelGearLoadCase)

    @property
    def zerol_bevel_gear_set_load_case(
        self: "CastSelf",
    ) -> "_7136.ZerolBevelGearSetLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7136,
        )

        return self.__parent__._cast(_7136.ZerolBevelGearSetLoadCase)

    @property
    def part_load_case(self: "CastSelf") -> "PartLoadCase":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class PartLoadCase(_2740.PartAnalysis):
    """PartLoadCase

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _PART_LOAD_CASE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def excitation_data_is_up_to_date(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ExcitationDataIsUpToDate

        if temp is None:
            return False

        return temp

    @property
    def harmonic_excitation_type(
        self: "Self",
    ) -> "enum_with_selected_value.EnumWithSelectedValue_HarmonicExcitationType":
        """EnumWithSelectedValue[mastapy._private.system_model.analyses_and_results.static_loads.HarmonicExcitationType]"""
        temp = self.wrapped.HarmonicExcitationType

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_HarmonicExcitationType.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @harmonic_excitation_type.setter
    @enforce_parameter_types
    def harmonic_excitation_type(
        self: "Self", value: "_7044.HarmonicExcitationType"
    ) -> None:
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_HarmonicExcitationType.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.HarmonicExcitationType = value

    @property
    def load_case_for_harmonic_excitation_type_advanced_system_deflection_current_load_case_set_up(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_StaticLoadCase":
        """ListWithSelectedItem[mastapy._private.system_model.analyses_and_results.static_loads.StaticLoadCase]"""
        temp = (
            self.wrapped.LoadCaseForHarmonicExcitationTypeAdvancedSystemDeflectionCurrentLoadCaseSetUp
        )

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_StaticLoadCase",
        )(temp)

    @load_case_for_harmonic_excitation_type_advanced_system_deflection_current_load_case_set_up.setter
    @enforce_parameter_types
    def load_case_for_harmonic_excitation_type_advanced_system_deflection_current_load_case_set_up(
        self: "Self", value: "_6951.StaticLoadCase"
    ) -> None:
        wrapper_type = (
            list_with_selected_item.ListWithSelectedItem_StaticLoadCase.wrapper_type()
        )
        enclosed_type = (
            list_with_selected_item.ListWithSelectedItem_StaticLoadCase.implicit_type()
        )
        value = wrapper_type[enclosed_type](
            value.wrapped if value is not None else None
        )
        self.wrapped.LoadCaseForHarmonicExcitationTypeAdvancedSystemDeflectionCurrentLoadCaseSetUp = (
            value
        )

    @property
    def use_this_load_case_for_advanced_system_deflection_current_load_case_set_up(
        self: "Self",
    ) -> "bool":
        """bool"""
        temp = (
            self.wrapped.UseThisLoadCaseForAdvancedSystemDeflectionCurrentLoadCaseSetUp
        )

        if temp is None:
            return False

        return temp

    @use_this_load_case_for_advanced_system_deflection_current_load_case_set_up.setter
    @enforce_parameter_types
    def use_this_load_case_for_advanced_system_deflection_current_load_case_set_up(
        self: "Self", value: "bool"
    ) -> None:
        self.wrapped.UseThisLoadCaseForAdvancedSystemDeflectionCurrentLoadCaseSetUp = (
            bool(value) if value is not None else False
        )

    @property
    def component_design(self: "Self") -> "_2524.Part":
        """mastapy._private.system_model.part_model.Part

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def static_load_case(self: "Self") -> "_6951.StaticLoadCase":
        """mastapy._private.system_model.analyses_and_results.static_loads.StaticLoadCase

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StaticLoadCase

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def time_series_load_case(self: "Self") -> "_6952.TimeSeriesLoadCase":
        """mastapy._private.system_model.analyses_and_results.static_loads.TimeSeriesLoadCase

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TimeSeriesLoadCase

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    def clear_user_specified_excitation_data_for_this_load_case(self: "Self") -> None:
        """Method does not return."""
        self.wrapped.ClearUserSpecifiedExcitationDataForThisLoadCase()

    def get_harmonic_load_data_for_import(self: "Self") -> "_1426.HarmonicLoadDataBase":
        """mastapy._private.electric_machines.harmonic_load_data.HarmonicLoadDataBase"""
        method_result = self.wrapped.GetHarmonicLoadDataForImport()
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @property
    def cast_to(self: "Self") -> "_Cast_PartLoadCase":
        """Cast to another type.

        Returns:
            _Cast_PartLoadCase
        """
        return _Cast_PartLoadCase(self)



"""LTCASettings"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import constructor, utility
from mastapy._private.utility import _1633
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_LTCA_SETTINGS = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.Cylindrical", "LTCASettings"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.gear_designs.cylindrical import _1089

    Self = TypeVar("Self", bound="LTCASettings")
    CastSelf = TypeVar("CastSelf", bound="LTCASettings._Cast_LTCASettings")


__docformat__ = "restructuredtext en"
__all__ = ("LTCASettings",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_LTCASettings:
    """Special nested class for casting LTCASettings to subclasses."""

    __parent__: "LTCASettings"

    @property
    def independent_reportable_properties_base(
        self: "CastSelf",
    ) -> "_1633.IndependentReportablePropertiesBase":
        pass

        return self.__parent__._cast(_1633.IndependentReportablePropertiesBase)

    @property
    def ltca_settings(self: "CastSelf") -> "LTCASettings":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class LTCASettings(_1633.IndependentReportablePropertiesBase["LTCASettings"]):
    """LTCASettings

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _LTCA_SETTINGS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def face_utilization_load_cutoff_parameter(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.FaceUtilizationLoadCutoffParameter

        if temp is None:
            return 0.0

        return temp

    @face_utilization_load_cutoff_parameter.setter
    @enforce_parameter_types
    def face_utilization_load_cutoff_parameter(self: "Self", value: "float") -> None:
        self.wrapped.FaceUtilizationLoadCutoffParameter = (
            float(value) if value is not None else 0.0
        )

    @property
    def include_extended_tip_contact(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.IncludeExtendedTipContact

        if temp is None:
            return False

        return temp

    @include_extended_tip_contact.setter
    @enforce_parameter_types
    def include_extended_tip_contact(self: "Self", value: "bool") -> None:
        self.wrapped.IncludeExtendedTipContact = (
            bool(value) if value is not None else False
        )

    @property
    def load_case_modifiable_settings(
        self: "Self",
    ) -> "_1089.LTCALoadCaseModifiableSettings":
        """mastapy._private.gears.gear_designs.cylindrical.LTCALoadCaseModifiableSettings

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LoadCaseModifiableSettings

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_LTCASettings":
        """Cast to another type.

        Returns:
            _Cast_LTCASettings
        """
        return _Cast_LTCASettings(self)



"""BearingSettingsItem"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import (
    constructor,
    conversion,
    enum_with_selected_value_runtime,
    utility,
)
from mastapy._private._internal.implicit import enum_with_selected_value, overridable
from mastapy._private.bearings import _1936
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private.utility.databases import _1879
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_BEARING_SETTINGS_ITEM = python_net_import(
    "SMT.MastaAPI.Bearings", "BearingSettingsItem"
)

if TYPE_CHECKING:
    from typing import Any, Type, Union, Tuple, TypeVar

    from mastapy._private.bearings import _1942, _1935

    Self = TypeVar("Self", bound="BearingSettingsItem")
    CastSelf = TypeVar(
        "CastSelf", bound="BearingSettingsItem._Cast_BearingSettingsItem"
    )


__docformat__ = "restructuredtext en"
__all__ = ("BearingSettingsItem",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_BearingSettingsItem:
    """Special nested class for casting BearingSettingsItem to subclasses."""

    __parent__: "BearingSettingsItem"

    @property
    def named_database_item(self: "CastSelf") -> "_1879.NamedDatabaseItem":
        return self.__parent__._cast(_1879.NamedDatabaseItem)

    @property
    def bearing_settings_item(self: "CastSelf") -> "BearingSettingsItem":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class BearingSettingsItem(_1879.NamedDatabaseItem):
    """BearingSettingsItem

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _BEARING_SETTINGS_ITEM

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def ball_bearing_weibull_reliability_slope(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.BallBearingWeibullReliabilitySlope

        if temp is None:
            return 0.0

        return temp

    @ball_bearing_weibull_reliability_slope.setter
    @enforce_parameter_types
    def ball_bearing_weibull_reliability_slope(self: "Self", value: "float") -> None:
        self.wrapped.BallBearingWeibullReliabilitySlope = (
            float(value) if value is not None else 0.0
        )

    @property
    def failure_probability_for_rating_life_percent(self: "Self") -> "_1942.RatingLife":
        """mastapy._private.bearings.RatingLife"""
        temp = self.wrapped.FailureProbabilityForRatingLifePercent

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(temp, "SMT.MastaAPI.Bearings.RatingLife")

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.bearings._1942", "RatingLife"
        )(value)

    @failure_probability_for_rating_life_percent.setter
    @enforce_parameter_types
    def failure_probability_for_rating_life_percent(
        self: "Self", value: "_1942.RatingLife"
    ) -> None:
        value = conversion.mp_to_pn_enum(value, "SMT.MastaAPI.Bearings.RatingLife")
        self.wrapped.FailureProbabilityForRatingLifePercent = value

    @property
    def include_exponent_and_reduction_factors_in_isots162812008(
        self: "Self",
    ) -> "_1935.ExponentAndReductionFactorsInISO16281Calculation":
        """mastapy._private.bearings.ExponentAndReductionFactorsInISO16281Calculation"""
        temp = self.wrapped.IncludeExponentAndReductionFactorsInISOTS162812008

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp,
            "SMT.MastaAPI.Bearings.ExponentAndReductionFactorsInISO16281Calculation",
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.bearings._1935",
            "ExponentAndReductionFactorsInISO16281Calculation",
        )(value)

    @include_exponent_and_reduction_factors_in_isots162812008.setter
    @enforce_parameter_types
    def include_exponent_and_reduction_factors_in_isots162812008(
        self: "Self", value: "_1935.ExponentAndReductionFactorsInISO16281Calculation"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value,
            "SMT.MastaAPI.Bearings.ExponentAndReductionFactorsInISO16281Calculation",
        )
        self.wrapped.IncludeExponentAndReductionFactorsInISOTS162812008 = value

    @property
    def lubricant_film_temperature_calculation_pressure_fed_grease_filled_bearings(
        self: "Self",
    ) -> "enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions":
        """EnumWithSelectedValue[mastapy._private.bearings.FluidFilmTemperatureOptions]"""
        temp = (
            self.wrapped.LubricantFilmTemperatureCalculationPressureFedGreaseFilledBearings
        )

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @lubricant_film_temperature_calculation_pressure_fed_grease_filled_bearings.setter
    @enforce_parameter_types
    def lubricant_film_temperature_calculation_pressure_fed_grease_filled_bearings(
        self: "Self", value: "_1936.FluidFilmTemperatureOptions"
    ) -> None:
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.LubricantFilmTemperatureCalculationPressureFedGreaseFilledBearings = (
            value
        )

    @property
    def lubricant_film_temperature_calculation_splashed_submerged_bearings(
        self: "Self",
    ) -> "enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions":
        """EnumWithSelectedValue[mastapy._private.bearings.FluidFilmTemperatureOptions]"""
        temp = self.wrapped.LubricantFilmTemperatureCalculationSplashedSubmergedBearings

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @lubricant_film_temperature_calculation_splashed_submerged_bearings.setter
    @enforce_parameter_types
    def lubricant_film_temperature_calculation_splashed_submerged_bearings(
        self: "Self", value: "_1936.FluidFilmTemperatureOptions"
    ) -> None:
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.LubricantFilmTemperatureCalculationSplashedSubmergedBearings = (
            value
        )

    @property
    def number_of_strips_for_roller_calculation(
        self: "Self",
    ) -> "overridable.Overridable_int":
        """Overridable[int]"""
        temp = self.wrapped.NumberOfStripsForRollerCalculation

        if temp is None:
            return 0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_int"
        )(temp)

    @number_of_strips_for_roller_calculation.setter
    @enforce_parameter_types
    def number_of_strips_for_roller_calculation(
        self: "Self", value: "Union[int, Tuple[int, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0, is_overridden
        )
        self.wrapped.NumberOfStripsForRollerCalculation = value

    @property
    def roller_bearing_weibull_reliability_slope(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.RollerBearingWeibullReliabilitySlope

        if temp is None:
            return 0.0

        return temp

    @roller_bearing_weibull_reliability_slope.setter
    @enforce_parameter_types
    def roller_bearing_weibull_reliability_slope(self: "Self", value: "float") -> None:
        self.wrapped.RollerBearingWeibullReliabilitySlope = (
            float(value) if value is not None else 0.0
        )

    @property
    def third_weibull_parameter(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.ThirdWeibullParameter

        if temp is None:
            return 0.0

        return temp

    @third_weibull_parameter.setter
    @enforce_parameter_types
    def third_weibull_parameter(self: "Self", value: "float") -> None:
        self.wrapped.ThirdWeibullParameter = float(value) if value is not None else 0.0

    @property
    def tolerance_used_for_diameter_warnings_and_database_filter(
        self: "Self",
    ) -> "float":
        """float"""
        temp = self.wrapped.ToleranceUsedForDiameterWarningsAndDatabaseFilter

        if temp is None:
            return 0.0

        return temp

    @tolerance_used_for_diameter_warnings_and_database_filter.setter
    @enforce_parameter_types
    def tolerance_used_for_diameter_warnings_and_database_filter(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.ToleranceUsedForDiameterWarningsAndDatabaseFilter = (
            float(value) if value is not None else 0.0
        )

    @property
    def use_plain_journal_bearing_misalignment_factors(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.UsePlainJournalBearingMisalignmentFactors

        if temp is None:
            return False

        return temp

    @use_plain_journal_bearing_misalignment_factors.setter
    @enforce_parameter_types
    def use_plain_journal_bearing_misalignment_factors(
        self: "Self", value: "bool"
    ) -> None:
        self.wrapped.UsePlainJournalBearingMisalignmentFactors = (
            bool(value) if value is not None else False
        )

    @property
    def cast_to(self: "Self") -> "_Cast_BearingSettingsItem":
        """Cast to another type.

        Returns:
            _Cast_BearingSettingsItem
        """
        return _Cast_BearingSettingsItem(self)



"""CutterGaugeLengths"""
from __future__ import annotations

from typing import TYPE_CHECKING
from enum import Enum

from mastapy._private._internal.python_net import python_net_import

_CUTTER_GAUGE_LENGTHS = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.Conical", "CutterGaugeLengths"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="CutterGaugeLengths")
    CastSelf = TypeVar("CastSelf", bound="CutterGaugeLengths._Cast_CutterGaugeLengths")


__docformat__ = "restructuredtext en"
__all__ = ("CutterGaugeLengths",)


class CutterGaugeLengths(Enum):
    """CutterGaugeLengths

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _CUTTER_GAUGE_LENGTHS

    _1143MM = 0
    _92075MM = 1


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


CutterGaugeLengths.__setattr__ = __enum_setattr
CutterGaugeLengths.__delattr__ = __enum_delattr



"""GearStabilityAnalysis"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.stability_analyses import _3943
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_GEAR_STABILITY_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StabilityAnalyses",
    "GearStabilityAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.part_model.gears import _2586
    from mastapy._private.system_model.analyses_and_results.stability_analyses import (
        _3868,
        _3875,
        _3876,
        _3877,
        _3880,
        _3893,
        _3896,
        _3912,
        _3913,
        _3919,
        _3928,
        _3932,
        _3935,
        _3938,
        _3967,
        _3976,
        _3979,
        _3980,
        _3981,
        _3994,
        _3997,
        _3887,
        _3945,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7713,
        _7710,
    )
    from mastapy._private.system_model.analyses_and_results import _2740, _2736, _2734

    Self = TypeVar("Self", bound="GearStabilityAnalysis")
    CastSelf = TypeVar(
        "CastSelf", bound="GearStabilityAnalysis._Cast_GearStabilityAnalysis"
    )


__docformat__ = "restructuredtext en"
__all__ = ("GearStabilityAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_GearStabilityAnalysis:
    """Special nested class for casting GearStabilityAnalysis to subclasses."""

    __parent__: "GearStabilityAnalysis"

    @property
    def mountable_component_stability_analysis(
        self: "CastSelf",
    ) -> "_3943.MountableComponentStabilityAnalysis":
        return self.__parent__._cast(_3943.MountableComponentStabilityAnalysis)

    @property
    def component_stability_analysis(
        self: "CastSelf",
    ) -> "_3887.ComponentStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3887,
        )

        return self.__parent__._cast(_3887.ComponentStabilityAnalysis)

    @property
    def part_stability_analysis(self: "CastSelf") -> "_3945.PartStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3945,
        )

        return self.__parent__._cast(_3945.PartStabilityAnalysis)

    @property
    def part_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7713.PartStaticLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7713,
        )

        return self.__parent__._cast(_7713.PartStaticLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7710.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7710,
        )

        return self.__parent__._cast(_7710.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2740.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2740

        return self.__parent__._cast(_2740.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2736.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2736

        return self.__parent__._cast(_2736.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3868.AGMAGleasonConicalGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3868,
        )

        return self.__parent__._cast(_3868.AGMAGleasonConicalGearStabilityAnalysis)

    @property
    def bevel_differential_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3875.BevelDifferentialGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3875,
        )

        return self.__parent__._cast(_3875.BevelDifferentialGearStabilityAnalysis)

    @property
    def bevel_differential_planet_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3876.BevelDifferentialPlanetGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3876,
        )

        return self.__parent__._cast(_3876.BevelDifferentialPlanetGearStabilityAnalysis)

    @property
    def bevel_differential_sun_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3877.BevelDifferentialSunGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3877,
        )

        return self.__parent__._cast(_3877.BevelDifferentialSunGearStabilityAnalysis)

    @property
    def bevel_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3880.BevelGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3880,
        )

        return self.__parent__._cast(_3880.BevelGearStabilityAnalysis)

    @property
    def concept_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3893.ConceptGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3893,
        )

        return self.__parent__._cast(_3893.ConceptGearStabilityAnalysis)

    @property
    def conical_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3896.ConicalGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3896,
        )

        return self.__parent__._cast(_3896.ConicalGearStabilityAnalysis)

    @property
    def cylindrical_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3912.CylindricalGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3912,
        )

        return self.__parent__._cast(_3912.CylindricalGearStabilityAnalysis)

    @property
    def cylindrical_planet_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3913.CylindricalPlanetGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3913,
        )

        return self.__parent__._cast(_3913.CylindricalPlanetGearStabilityAnalysis)

    @property
    def face_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3919.FaceGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3919,
        )

        return self.__parent__._cast(_3919.FaceGearStabilityAnalysis)

    @property
    def hypoid_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3928.HypoidGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3928,
        )

        return self.__parent__._cast(_3928.HypoidGearStabilityAnalysis)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3932.KlingelnbergCycloPalloidConicalGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3932,
        )

        return self.__parent__._cast(
            _3932.KlingelnbergCycloPalloidConicalGearStabilityAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3935.KlingelnbergCycloPalloidHypoidGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3935,
        )

        return self.__parent__._cast(
            _3935.KlingelnbergCycloPalloidHypoidGearStabilityAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3938.KlingelnbergCycloPalloidSpiralBevelGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3938,
        )

        return self.__parent__._cast(
            _3938.KlingelnbergCycloPalloidSpiralBevelGearStabilityAnalysis
        )

    @property
    def spiral_bevel_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3967.SpiralBevelGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3967,
        )

        return self.__parent__._cast(_3967.SpiralBevelGearStabilityAnalysis)

    @property
    def straight_bevel_diff_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3976.StraightBevelDiffGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3976,
        )

        return self.__parent__._cast(_3976.StraightBevelDiffGearStabilityAnalysis)

    @property
    def straight_bevel_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3979.StraightBevelGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3979,
        )

        return self.__parent__._cast(_3979.StraightBevelGearStabilityAnalysis)

    @property
    def straight_bevel_planet_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3980.StraightBevelPlanetGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3980,
        )

        return self.__parent__._cast(_3980.StraightBevelPlanetGearStabilityAnalysis)

    @property
    def straight_bevel_sun_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3981.StraightBevelSunGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3981,
        )

        return self.__parent__._cast(_3981.StraightBevelSunGearStabilityAnalysis)

    @property
    def worm_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3994.WormGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3994,
        )

        return self.__parent__._cast(_3994.WormGearStabilityAnalysis)

    @property
    def zerol_bevel_gear_stability_analysis(
        self: "CastSelf",
    ) -> "_3997.ZerolBevelGearStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _3997,
        )

        return self.__parent__._cast(_3997.ZerolBevelGearStabilityAnalysis)

    @property
    def gear_stability_analysis(self: "CastSelf") -> "GearStabilityAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class GearStabilityAnalysis(_3943.MountableComponentStabilityAnalysis):
    """GearStabilityAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _GEAR_STABILITY_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def component_design(self: "Self") -> "_2586.Gear":
        """mastapy._private.system_model.part_model.gears.Gear

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_GearStabilityAnalysis":
        """Cast to another type.

        Returns:
            _Cast_GearStabilityAnalysis
        """
        return _Cast_GearStabilityAnalysis(self)



"""ElectricMachineDQModel"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_ELECTRIC_MACHINE_DQ_MODEL = python_net_import(
    "SMT.MastaAPI.ElectricMachines.Results", "ElectricMachineDQModel"
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.electric_machines import _1358
    from mastapy._private.electric_machines.results import _1386, _1388

    Self = TypeVar("Self", bound="ElectricMachineDQModel")
    CastSelf = TypeVar(
        "CastSelf", bound="ElectricMachineDQModel._Cast_ElectricMachineDQModel"
    )


__docformat__ = "restructuredtext en"
__all__ = ("ElectricMachineDQModel",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ElectricMachineDQModel:
    """Special nested class for casting ElectricMachineDQModel to subclasses."""

    __parent__: "ElectricMachineDQModel"

    @property
    def linear_dq_model(self: "CastSelf") -> "_1386.LinearDQModel":
        from mastapy._private.electric_machines.results import _1386

        return self.__parent__._cast(_1386.LinearDQModel)

    @property
    def non_linear_dq_model(self: "CastSelf") -> "_1388.NonLinearDQModel":
        from mastapy._private.electric_machines.results import _1388

        return self.__parent__._cast(_1388.NonLinearDQModel)

    @property
    def electric_machine_dq_model(self: "CastSelf") -> "ElectricMachineDQModel":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ElectricMachineDQModel(_0.APIBase):
    """ElectricMachineDQModel

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ELECTRIC_MACHINE_DQ_MODEL

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def conductor_dimension_for_skin_depth_calculation(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConductorDimensionForSkinDepthCalculation

        if temp is None:
            return 0.0

        return temp

    @property
    def current_angle_to_maximise_torque_at_maximum_current_at_reference_temperature(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = (
            self.wrapped.CurrentAngleToMaximiseTorqueAtMaximumCurrentAtReferenceTemperature
        )

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_peak_phase_current(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumPeakPhaseCurrent

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_peak_phase_supply_voltage(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumPeakPhaseSupplyVoltage

        if temp is None:
            return 0.0

        return temp

    @property
    def name(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Name

        if temp is None:
            return ""

        return temp

    @property
    def number_of_phases(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfPhases

        if temp is None:
            return 0

        return temp

    @property
    def number_of_pole_pairs(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfPolePairs

        if temp is None:
            return 0

        return temp

    @property
    def permanent_magnet_flux_linkage_at_reference_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PermanentMagnetFluxLinkageAtReferenceTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def phase_resistance_at_reference_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PhaseResistanceAtReferenceTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def steady_state_short_circuit_current_at_reference_temperature(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SteadyStateShortCircuitCurrentAtReferenceTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def temperature_coefficient_for_remanence(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TemperatureCoefficientForRemanence

        if temp is None:
            return 0.0

        return temp

    @property
    def temperature_coefficient_for_winding_resistivity(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TemperatureCoefficientForWindingResistivity

        if temp is None:
            return 0.0

        return temp

    @property
    def winding_connection(self: "Self") -> "_1358.WindingConnection":
        """mastapy._private.electric_machines.WindingConnection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.WindingConnection

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.ElectricMachines.WindingConnection"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.electric_machines._1358", "WindingConnection"
        )(value)

    @property
    def winding_material_relative_permeability_at_reference_temperature(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.WindingMaterialRelativePermeabilityAtReferenceTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def winding_resistivity_at_reference_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.WindingResistivityAtReferenceTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else "")

    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else "")

    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else "")

    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(
            report_name if report_name else ""
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_ElectricMachineDQModel":
        """Cast to another type.

        Returns:
            _Cast_ElectricMachineDQModel
        """
        return _Cast_ElectricMachineDQModel(self)
